==> datasketches-java-4.0.0-sources.jar: org/apache/datasketches/quantiles/CompactDoublesSketch.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.datasketches.quantiles;

import org.apache.datasketches.common.SketchesStateException;
import org.apache.datasketches.memory.Memory;

/**
 * Compact sketches are inherently <i>read ony</i>.
 * @author Jon Malkin
 */
public abstract class CompactDoublesSketch extends DoublesSketch {
  CompactDoublesSketch(final int k) {
    super(k);
  }

  public static CompactDoublesSketch heapify(final Memory srcMem) {
    return HeapCompactDoublesSketch.heapifyInstance(srcMem);
  }

  @Override
  boolean isCompact() {
    return true;
  }

  @Override
  public boolean isReadOnly() {
    return false;
  }

  @Override
  public void reset() {
    throw new SketchesStateException("Cannot reset a compact sketch, which is read-only.");
  }

  @Override
  public void update(final double quantile) {
    throw new SketchesStateException("Cannot update a compact sketch, which is read-only.");
  }

}

==> datasketches-java-6.2.0-sources.jar: org/apache/datasketches/quantiles/CompactDoublesSketch.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.datasketches.quantiles;

import org.apache.datasketches.common.SketchesStateException;
import org.apache.datasketches.memory.Memory;

/**
 * Compact sketches are inherently <i>read only</i>.
 * @author Jon Malkin
 */
public abstract class CompactDoublesSketch extends DoublesSketch {
  CompactDoublesSketch(final int k) {
    super(k);
  }

  public static CompactDoublesSketch heapify(final Memory srcMem) {
    return HeapCompactDoublesSketch.heapifyInstance(srcMem);
  }

  @Override
  boolean isCompact() {
    return true;
  }

  @Override
  public boolean isReadOnly() {
    return false;
  }

  @Override
  public void reset() {
    throw new SketchesStateException("Cannot reset a compact sketch, which is read-only.");
  }

  @Override
  public void update(final double quantile) {
    throw new SketchesStateException("Cannot update a compact sketch, which is read-only.");
  }

}
